@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef NOTESAGENTALARMDIALOG_H
 #define NOTESAGENTALARMDIALOG_H
-#include <QDialog>
 #include <Item>
+#include <QDialog>
 class QListWidget;
 class QLabel;
 class QListWidgetItem;
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteListWidget;
 }
 class KJob;
