@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notesagentnotedialog.h"
+#include "attributes/notedisplayattribute.h"
 #include "notesagent_debug.h"
 #include <ItemFetchJob>
 #include <ItemFetchScope>
-#include "attributes/notedisplayattribute.h"
-#include <KPIMTextEdit/RichTextEditorWidget>
 #include <KPIMTextEdit/RichTextEditor>
+#include <KPIMTextEdit/RichTextEditorWidget>
 
 #include <KSharedConfig>
 
@@ -17,16 +17,16 @@
 
 #include <QIcon>
 
-#include <QLineEdit>
-#include <QVBoxLayout>
-#include <QDialogButtonBox>
 #include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QLineEdit>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 NotesAgentNoteDialog::NotesAgentNoteDialog(QWidget *parent)
     : QDialog(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
 
@@ -53,9 +53,9 @@ NotesAgentNoteDialog::~NotesAgentNoteDialog()
 void NotesAgentNoteDialog::setNoteId(Akonadi::Item::Id id)
 {
     Akonadi::Item item(id);
-    auto *job = new Akonadi::ItemFetchJob(item, this);
+    auto job = new Akonadi::ItemFetchJob(item, this);
     job->fetchScope().fetchFullPayload(true);
-    job->fetchScope().fetchAttribute< NoteShared::NoteDisplayAttribute >();
+    job->fetchScope().fetchAttribute<NoteShared::NoteDisplayAttribute>();
     connect(job, &Akonadi::ItemFetchJob::result, this, &NotesAgentNoteDialog::slotFetchItem);
 }
 
@@ -65,7 +65,7 @@ void NotesAgentNoteDialog::slotFetchItem(KJob *job)
         qCDebug(NOTESAGENT_LOG) << "fetch item failed " << job->errorString();
         return;
     }
-    auto *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
     const Akonadi::Item::List lstItem = itemFetchJob->items();
     if (!lstItem.isEmpty()) {
         const Akonadi::Item item = lstItem.first();
@@ -87,7 +87,7 @@ void NotesAgentNoteDialog::slotFetchItem(KJob *job)
             const auto *attr = item.attribute<NoteShared::NoteDisplayAttribute>();
             if (attr) {
                 mNote->editor()->setTextColor(attr->backgroundColor());
-                //TODO add background color.
+                // TODO add background color.
             }
         }
     }
