@@ -9,18 +9,19 @@
 #ifndef NOTEALARMDIALOG_H
 #define NOTEALARMDIALOG_H
 
-#include <QDialog>
 #include "noteshared_export.h"
+#include <QDialog>
 class QDateTime;
 class QAbstractButton;
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteAlarmDialogPrivate;
 class NOTESHARED_EXPORT NoteAlarmDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit NoteAlarmDialog(const QString &caption, QWidget *parent = nullptr);
-    ~NoteAlarmDialog();
+    ~NoteAlarmDialog() override;
     void setAlarm(const QDateTime &dateTime);
     Q_REQUIRED_RESULT QDateTime alarm() const;
 
