@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,13 +8,14 @@
 
 #include <AkonadiWidgets/CollectionDialog>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class SelectedNotefolderDialog : public Akonadi::CollectionDialog
 {
     Q_OBJECT
 public:
     explicit SelectedNotefolderDialog(QWidget *parent = nullptr);
-    ~SelectedNotefolderDialog();
+    ~SelectedNotefolderDialog() override;
 
 private:
     void readConfig();
