@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,13 +8,14 @@
 
 #include <KPIMTextEdit/RichTextEditorWidget>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteEditor : public KPIMTextEdit::RichTextEditorWidget
 {
     Q_OBJECT
 public:
     explicit NoteEditor(QWidget *parent);
-    ~NoteEditor();
+    ~NoteEditor() override;
 };
 }
 
