@@ -1,22 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "noteutils.h"
-#include "network/notesnetworksender.h"
-#include "network/notehostdialog.h"
 #include "attributes/notedisplayattribute.h"
+#include "network/notehostdialog.h"
+#include "network/notesnetworksender.h"
 #include "notesharedglobalconfig.h"
-#include <KProcess>
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
+#include <KProcess>
 
 #include <KMime/KMimeMessage>
 
-#include <QRegularExpression>
-#include <QPointer>
 #include <QApplication>
+#include <QPointer>
+#include <QRegularExpression>
 #include <QSslSocket>
 
 using namespace NoteShared;
@@ -28,11 +28,7 @@ NoteUtils::NoteUtils()
 bool NoteUtils::sendToMail(QWidget *parent, const QString &title, const QString &message)
 {
     // get the mail action command
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList cmd_list = NoteShared::NoteSharedGlobalConfig::mailAction().split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
     const QStringList cmd_list = NoteShared::NoteSharedGlobalConfig::mailAction().split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
     if (cmd_list.isEmpty()) {
         KMessageBox::sorry(parent, i18n("Please configure send mail action."));
         return false;
@@ -68,16 +64,16 @@ void NoteUtils::sendToNetwork(QWidget *parent, const QString &title, const QStri
         }
         quint16 port = hostDlg->port();
 
-        if (!port) {   // not specified, use default
+        if (!port) { // not specified, use default
             port = NoteShared::NoteSharedGlobalConfig::port();
         }
 
         // Send the note
         auto socket = new QSslSocket;
         socket->connectToHost(host, port);
-        auto *sender = new NoteShared::NotesNetworkSender(socket);
+        auto sender = new NoteShared::NotesNetworkSender(socket);
         sender->setSenderId(NoteShared::NoteSharedGlobalConfig::senderID());
-        sender->setNote(title, message);   // FIXME: plainText ??
+        sender->setNote(title, message); // FIXME: plainText ??
     }
     delete hostDlg;
 }
@@ -103,36 +99,34 @@ QString NoteUtils::createToolTip(const Akonadi::Item &item)
             const bool textIsLeftToRight = (QApplication::layoutDirection() == Qt::LeftToRight);
             const QString textDirection = textIsLeftToRight ? QStringLiteral("left") : QStringLiteral("right");
 
-            tip = QStringLiteral(
-                "<table width=\"100%\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">"
-                );
+            tip = QStringLiteral("<table width=\"100%\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">");
             tip += QStringLiteral(
-                "<tr>" \
-                "<td bgcolor=\"%1\" align=\"%4\" valign=\"middle\">" \
-                "<div style=\"color: %2; font-weight: bold;\">" \
-                "%3" \
-                "</div>" \
-                "</td>" \
-                "</tr>"
-                ).arg(bckColorName, txtColorName, realName.toHtmlEscaped(), textDirection);
+                       "<tr>"
+                       "<td bgcolor=\"%1\" align=\"%4\" valign=\"middle\">"
+                       "<div style=\"color: %2; font-weight: bold;\">"
+                       "%3"
+                       "</div>"
+                       "</td>"
+                       "</tr>")
+                       .arg(bckColorName, txtColorName, realName.toHtmlEscaped(), textDirection);
             const QString htmlCodeForStandardRow = QStringLiteral(
-                "<tr>" \
-                "<td bgcolor=\"%1\" align=\"left\" valign=\"top\">" \
-                "<div style=\"color: %2;\">" \
-                "%3" \
-                "</div>" \
-                "</td>" \
+                "<tr>"
+                "<td bgcolor=\"%1\" align=\"left\" valign=\"top\">"
+                "<div style=\"color: %2;\">"
+                "%3"
+                "</div>"
+                "</td>"
                 "</tr>");
 
             QString content = description;
             if (!content.trimmed().isEmpty()) {
-                tip += htmlCodeForStandardRow.arg(bckColorName, txtColorName, isRichText ? content : content.replace(QLatin1Char('\n'), QStringLiteral("<br>")));
+                tip +=
+                    htmlCodeForStandardRow.arg(bckColorName, txtColorName, isRichText ? content : content.replace(QLatin1Char('\n'), QStringLiteral("<br>")));
             }
             tip += QLatin1String(
-                "</table" \
-                "</td>" \
-                "</tr>"
-                );
+                "</table"
+                "</td>"
+                "</tr>");
         }
     }
     return tip;
