@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTECOLLECTIONCONFIGWIDGET_H
 #define KNOTECOLLECTIONCONFIGWIDGET_H
 
-#include <QWidget>
 #include <AkonadiCore/Collection>
 #include <QIdentityProxyModel>
 #include <QModelIndex>
+#include <QWidget>
 class QSortFilterProxyModel;
-namespace Akonadi {
+namespace Akonadi
+{
 class EntityTreeModel;
 class ChangeRecorder;
 class CollectionRequester;
@@ -42,7 +43,7 @@ class KNoteCollectionConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit KNoteCollectionConfigWidget(QWidget *parent = nullptr);
-    ~KNoteCollectionConfigWidget();
+    ~KNoteCollectionConfigWidget() override;
 
     void updateCollectionsRecursive();
 
@@ -60,6 +61,7 @@ private Q_SLOTS:
     void slotRenameCollection();
     void slotUpdateButtons();
     void slotCollectionModifyFinished(KJob *);
+
 private:
     void forceStatus(const QModelIndex &parent, bool status);
     Akonadi::EntityTreeView *mFolderView = nullptr;
