@@ -1,15 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTEDELETESELECTEDNOTESDIALOG_H
 #define KNOTEDELETESELECTEDNOTESDIALOG_H
 
-#include <QDialog>
 #include <AkonadiCore/Item>
+#include <QDialog>
 class QPushButton;
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteListWidget;
 }
 
@@ -18,7 +19,7 @@ class KNoteDeleteSelectedNotesDialog : public QDialog
     Q_OBJECT
 public:
     explicit KNoteDeleteSelectedNotesDialog(QWidget *parent = nullptr);
-    ~KNoteDeleteSelectedNotesDialog();
+    ~KNoteDeleteSelectedNotesDialog() override;
 
     void setNotes(const Akonadi::Item::List &notes);
 
@@ -26,6 +27,7 @@ public:
 
 private Q_SLOTS:
     void slotDeleteNoteSelectionChanged();
+
 private:
     void readConfig();
     void writeConfig();
