@@ -2,7 +2,7 @@
   This file is part of Kontact.
 
   SPDX-FileCopyrightText: 2003 Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
@@ -16,16 +16,19 @@
 
 #include <KViewStateMaintainer>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NotesChangeRecorder;
 class NotesAkonadiTreeModel;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ETMViewStateSaver;
 }
 
-namespace KontactInterface {
+namespace KontactInterface
+{
 class Plugin;
 }
 
@@ -52,6 +55,7 @@ private Q_SLOTS:
     void updateFolderList();
     void slotSelectNote(const QString &note);
     void slotPopupMenu(const QString &);
+
 private:
     void deleteNote(const QString &note);
     void displayNotes(const QModelIndex &parent, int &counter);
