@@ -7,17 +7,17 @@
 *******************************************************************/
 
 #include "knote.h"
-#include "knotes_debug.h"
-#include "knotedisplaysettings.h"
-#include "knoteedit.h"
-#include "knotesglobalconfig.h"
-#include "noteutils.h"
 #include "alarms/notealarmdialog.h"
 #include "attributes/notealarmattribute.h"
 #include "attributes/notedisplayattribute.h"
 #include "attributes/notelockattribute.h"
 #include "configdialog/knotesimpleconfigdialog.h"
+#include "knotedisplaysettings.h"
+#include "knoteedit.h"
+#include "knotes_debug.h"
+#include "knotesglobalconfig.h"
 #include "notes/knotebutton.h"
+#include "noteutils.h"
 #include "print/knoteprinter.h"
 #include "print/knoteprintobject.h"
 #include "print/knoteprintselectthemedialog.h"
@@ -50,8 +50,8 @@
 #include <QMimeData>
 #include <QPointer>
 #include <QSizeGrip>
-#include <QVBoxLayout>
 #include <QTextEdit>
+#include <QVBoxLayout>
 
 #if KDEPIM_HAVE_X11
 #include <KWindowSystem/NETWM>
@@ -71,7 +71,7 @@ KNote::KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allow
         mDisplayAttribute->setDisplayAttribute(mItem.attribute<NoteShared::NoteDisplayAttribute>());
     } else {
         setDisplayDefaultValue();
-        //save default display value
+        // save default display value
     }
     setAcceptDrops(true);
     setAttribute(Qt::WA_DeleteOnClose);
@@ -95,7 +95,7 @@ KNote::~KNote()
 void KNote::setDisplayDefaultValue()
 {
     KNoteUtils::setDefaultValue(mItem);
-    auto *job = new Akonadi::ItemModifyJob(mItem);
+    auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
     qCDebug(KNOTES_LOG) << "setDisplayDefaultValue slotNoteSaved(KJob*)";
 #endif
@@ -118,7 +118,7 @@ void KNote::setChangeItem(const Akonadi::Item &item, const QSet<QByteArray> &set
         qCDebug(KNOTES_LOG) << " ATR:NoteDisplayAttribute";
         slotApplyConfig();
     }
-    //TODO update display/content etc.
+    // TODO update display/content etc.
     updateLabelAlignment();
 }
 
@@ -128,10 +128,10 @@ void KNote::slotKill(bool force)
         && KMessageBox::warningContinueCancel(this,
                                               i18n("<qt>Do you really want to delete note <b>%1</b>?</qt>", m_label->text()),
                                               i18n("Confirm Delete"),
-                                              KGuiItem(i18n("&Delete"),
-                                                       QStringLiteral("edit-delete")),
+                                              KGuiItem(i18n("&Delete"), QStringLiteral("edit-delete")),
                                               KStandardGuiItem::cancel(),
-                                              QStringLiteral("ConfirmDeleteNote")) != KMessageBox::Continue) {
+                                              QStringLiteral("ConfirmDeleteNote"))
+            != KMessageBox::Continue) {
         return;
     }
 
@@ -146,8 +146,7 @@ void KNote::saveNote(bool force, bool sync)
         return;
     }
     bool needToSave = false;
-    auto *attribute
-        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    auto *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     const QPoint notePosition = pos();
     if (attribute->position() != notePosition) {
         needToSave = true;
@@ -179,7 +178,7 @@ void KNote::saveNote(bool force, bool sync)
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "save Note slotClose() slotNoteSaved(KJob*) : sync" << sync;
 #endif
-        auto *job = new Akonadi::ItemModifyJob(mItem);
+        auto job = new Akonadi::ItemModifyJob(mItem);
         if (sync) {
             job->exec();
         } else {
@@ -221,7 +220,7 @@ void KNote::setName(const QString &name)
     m_label->setText(name);
     updateLabelAlignment();
 
-    if (m_editor) {      // not called from CTOR?
+    if (m_editor) { // not called from CTOR?
         saveNote();
     }
     setWindowTitle(name);
@@ -253,10 +252,8 @@ void KNote::slotRename()
     // pop up dialog to get the new name
     bool ok;
     const QString oldName = m_label->text();
-    const QString newName = QInputDialog::getText(this, QString(),
-                                                  i18n("Please enter the new name:"),
-                                                  QLineEdit::Normal, m_label->text(), &ok);
-    if (!ok || (oldName == newName)) {   // handle cancel
+    const QString newName = QInputDialog::getText(this, QString(), i18n("Please enter the new name:"), QLineEdit::Normal, m_label->text(), &ok);
+    if (!ok || (oldName == newName)) { // handle cancel
         return;
     }
 
@@ -280,7 +277,7 @@ void KNote::slotUpdateReadOnly()
     }
     if (!mBlockSave) {
         updateAllAttributes();
-        auto *job = new Akonadi::ItemModifyJob(mItem);
+        auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << " void KNote::slotUpdateReadOnly() slotNoteSaved(KJob*)";
 #endif
@@ -320,8 +317,7 @@ void KNote::slotUpdateReadOnly()
 
 void KNote::updateAllAttributes()
 {
-    auto *attribute
-        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    auto *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
 #if KDEPIM_HAVE_X11
     KWindowInfo info(winId(), NET::WMDesktop);
     const int count = KWindowSystem::numberOfDesktops();
@@ -344,7 +340,7 @@ void KNote::slotClose()
 {
     updateAllAttributes();
     m_editor->clearFocus();
-    auto *job = new Akonadi::ItemModifyJob(mItem);
+    auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
     qCDebug(KNOTES_LOG) << "slotClose() slotNoteSaved(KJob*)";
 #endif
@@ -362,8 +358,7 @@ void KNote::slotSetAlarm()
         bool needToModify = true;
         QDateTime dateTime = dlg->alarm();
         if (dateTime.isValid()) {
-            auto *attribute
-                = mItem.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
+            auto *attribute = mItem.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
             attribute->setDateTime(dateTime);
         } else {
             if (mItem.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
@@ -373,9 +368,9 @@ void KNote::slotSetAlarm()
             }
         }
         if (needToModify) {
-            //Verify it!
+            // Verify it!
             saveNoteContent();
-            auto *job = new Akonadi::ItemModifyJob(mItem);
+            auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
             qCDebug(KNOTES_LOG) << "setAlarm() slotNoteSaved(KJob*)";
 #endif
@@ -396,7 +391,7 @@ void KNote::saveNoteContent()
     message->date(true)->setDateTime(QDateTime::currentDateTime());
     message->mainBodyPart()->fromUnicodeString(text().isEmpty() ? QStringLiteral(" ") : text());
 
-    auto *header = new KMime::Headers::Generic("X-Cursor-Position");
+    auto header = new KMime::Headers::Generic("X-Cursor-Position");
     header->fromUnicodeString(QString::number(m_editor->cursorPositionFromStart()), "utf-8");
     message->setHeader(header);
 
@@ -409,8 +404,7 @@ void KNote::slotPreferences()
 {
     // create a new preferences dialog...
     QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog(name(), this);
-    auto *attribute
-        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    auto *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     attribute->setSize(QSize(width(), height()));
 
     dialog->load(mItem, m_editor->acceptRichText());
@@ -420,7 +414,7 @@ void KNote::slotPreferences()
         dialog->save(mItem, isRichText);
         m_editor->setAcceptRichText(isRichText);
         saveNoteContent();
-        auto *job = new Akonadi::ItemModifyJob(mItem);
+        auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "slotPreference slotNoteSaved(KJob*)";
 #endif
@@ -508,7 +502,8 @@ void KNote::slotSaveAs()
         && KMessageBox::warningContinueCancel(this,
                                               i18n("<qt>A file named <b>%1</b> already exists.<br />"
                                                    "Are you sure you want to overwrite it?</qt>",
-                                                   QFileInfo(file).fileName())) != KMessageBox::Continue) {
+                                                   QFileInfo(file).fileName()))
+            != KMessageBox::Continue) {
         return;
     }
 
@@ -518,7 +513,7 @@ void KNote::slotSaveAs()
             QString htmlStr = m_editor->toHtml();
             htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""),
                             QStringLiteral("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
-            stream <<  htmlStr;
+            stream << htmlStr;
         } else {
             stream << m_editor->toPlainText();
         }
@@ -528,7 +523,7 @@ void KNote::slotSaveAs()
 void KNote::slotPopupActionToDesktop(QAction *act)
 {
     const int id = act->data().toInt();
-    toDesktop(id);   // compensate for the menu separator, -1 == all desktops
+    toDesktop(id); // compensate for the menu separator, -1 == all desktops
 }
 
 // ------------------ private slots (configuration) ------------------ //
@@ -543,7 +538,9 @@ void KNote::slotApplyConfig()
     setColor(mDisplayAttribute->foregroundColor(), mDisplayAttribute->backgroundColor());
 
     updateLayout();
+#if KDEPIM_HAVE_X11
     slotUpdateShowInTaskbar();
+#endif
     resize(mDisplayAttribute->size());
 }
 
@@ -570,8 +567,7 @@ void KNote::updateKeepAboveBelow(bool save)
 #else
     NET::States state = {}; // neutral state, TODO
 #endif
-    auto *attribute
-        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    auto *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     if (m_keepAbove->isChecked()) {
         attribute->setKeepAbove(true);
         attribute->setKeepBelow(false);
@@ -588,7 +584,7 @@ void KNote::updateKeepAboveBelow(bool save)
     }
     if (!mBlockSave && save) {
         saveNoteContent();
-        auto *job = new Akonadi::ItemModifyJob(mItem);
+        auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "slotUpdateKeepAboveBelow slotNoteSaved(KJob*)";
 #endif
@@ -600,8 +596,7 @@ void KNote::slotUpdateShowInTaskbar()
 {
 #if KDEPIM_HAVE_X11
     if (!mDisplayAttribute->showInTaskbar()) {
-        KWindowSystem::setState(winId(), KWindowInfo(winId(),
-                                                     NET::WMState).state() | NET::SkipTaskbar);
+        KWindowSystem::setState(winId(), KWindowInfo(winId(), NET::WMState).state() | NET::SkipTaskbar);
     } else {
         KWindowSystem::clearState(winId(), NET::SkipTaskbar);
     }
@@ -620,13 +615,12 @@ void KNote::slotUpdateDesktopActions()
         act->setChecked(true);
         act->setData(NETWinInfo::OnAllDesktops);
     }
-    auto *separator = new QAction(m_toDesktop);
+    auto separator = new QAction(m_toDesktop);
     separator->setSeparator(true);
     m_toDesktop->addAction(separator);
     const int count = KWindowSystem::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
-        QAction *desktopAct
-            = m_toDesktop->addAction(QStringLiteral("&%1 %2").arg(n).arg(KWindowSystem::desktopName(n)));
+        QAction *desktopAct = m_toDesktop->addAction(QStringLiteral("&%1 %2").arg(n).arg(KWindowSystem::desktopName(n)));
         desktopAct->setData(n);
         if (info.isOnDesktop(n)) {
             desktopAct->setChecked(true);
@@ -664,8 +658,7 @@ void KNote::createActions()
     actionCollection()->addAction(QStringLiteral("rename_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotRename);
 
-    m_readOnly = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-locked")),
-                                   i18n("Lock"), this);
+    m_readOnly = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-locked")), i18n("Lock"), this);
     actionCollection()->addAction(QStringLiteral("lock_note"), m_readOnly);
     connect(m_readOnly, &KToggleAction::triggered, this, &KNote::slotUpdateReadOnly);
     m_readOnly->setCheckedState(KGuiItem(i18n("Unlock"), QStringLiteral("object-unlocked")));
@@ -679,8 +672,7 @@ void KNote::createActions()
     actionCollection()->addAction(QStringLiteral("delete_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotKill);
 
-    action = new QAction(QIcon::fromTheme(QStringLiteral("knotes_alarm")), i18n("Set Alarm..."),
-                         this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("knotes_alarm")), i18n("Set Alarm..."), this);
     actionCollection()->addAction(QStringLiteral("set_alarm"), action);
     connect(action, &QAction::triggered, this, &KNote::slotSetAlarm);
 
@@ -692,8 +684,7 @@ void KNote::createActions()
     actionCollection()->addAction(QStringLiteral("mail_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotMail);
 
-    action = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Save As..."),
-                         this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Save As..."), this);
     actionCollection()->addAction(QStringLiteral("save_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotSaveAs);
     action = actionCollection()->addAction(KStandardAction::Print, QStringLiteral("print_note"));
@@ -706,23 +697,19 @@ void KNote::createActions()
     actionCollection()->addAction(QStringLiteral("configure_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotPreferences);
 
-    m_keepAbove = new KToggleAction(QIcon::fromTheme(QStringLiteral("go-up")),
-                                    i18n("Keep Above Others"), this);
+    m_keepAbove = new KToggleAction(QIcon::fromTheme(QStringLiteral("go-up")), i18n("Keep Above Others"), this);
     actionCollection()->addAction(QStringLiteral("keep_above"), m_keepAbove);
     connect(m_keepAbove, &KToggleAction::triggered, this, &KNote::slotKeepAbove);
 
-    m_keepBelow = new KToggleAction(QIcon::fromTheme(QStringLiteral("go-down")),
-                                    i18n("Keep Below Others"), this);
+    m_keepBelow = new KToggleAction(QIcon::fromTheme(QStringLiteral("go-down")), i18n("Keep Below Others"), this);
     actionCollection()->addAction(QStringLiteral("keep_below"), m_keepBelow);
     connect(m_keepBelow, &KToggleAction::triggered, this, &KNote::slotKeepBelow);
 
 #if KDEPIM_HAVE_X11
     m_toDesktop = new KSelectAction(i18n("To Desktop"), this);
     actionCollection()->addAction(QStringLiteral("to_desktop"), m_toDesktop);
-    connect(m_toDesktop, qOverload<QAction *>(&KSelectAction::triggered),
-            this, &KNote::slotPopupActionToDesktop);
-    connect(m_toDesktop->menu(), &QMenu::aboutToShow,
-            this, &KNote::slotUpdateDesktopActions);
+    connect(m_toDesktop, qOverload<QAction *>(&KSelectAction::triggered), this, &KNote::slotPopupActionToDesktop);
+    connect(m_toDesktop->menu(), &QMenu::aboutToShow, this, &KNote::slotUpdateDesktopActions);
     // initially populate it, otherwise stays disabled
     slotUpdateDesktopActions();
 #endif
@@ -730,7 +717,7 @@ void KNote::createActions()
     action = new QAction(i18n("Walk Through Notes"), this);
     actionCollection()->addAction(QStringLiteral("walk_notes"), action);
     connect(action, &QAction::triggered, this, &KNote::sigShowNextNote);
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::SHIFT + Qt::Key_Backtab));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::SHIFT | Qt::Key_Backtab));
 
     actionCollection()->addAssociatedWidget(this);
     const auto lst = actionCollection()->actions();
@@ -738,7 +725,7 @@ void KNote::createActions()
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     }
     if (mAllowDebugAkonadiSearch) {
-        //Don't translate it it's just for debugging
+        // Don't translate it it's just for debugging
         action = new QAction(QStringLiteral("Debug Akonadi Search..."), this);
         actionCollection()->addAction(QStringLiteral("debug_akonadi_search"), action);
         connect(action, &QAction::triggered, this, &KNote::slotDebugAkonadiSearch);
@@ -758,7 +745,7 @@ void KNote::createNoteHeader()
         }
     }
 
-    auto *headerLayout = new QBoxLayout(headerLayoutDirection);
+    auto headerLayout = new QBoxLayout(headerLayoutDirection);
 
     // create header label
     m_label = new QLabel(this);
@@ -767,7 +754,7 @@ void KNote::createNoteHeader()
     m_label->setBackgroundRole(QPalette::Base);
     m_label->setLineWidth(0);
     m_label->setAutoFillBackground(true);
-    m_label->installEventFilter(this);    // receive events ( for dragging &
+    m_label->installEventFilter(this); // receive events ( for dragging &
     // action menu )
     m_button = new KNoteButton(QStringLiteral("knotes_close"), this);
     headerLayout->addWidget(m_button);
@@ -779,17 +766,17 @@ void KNote::createNoteHeader()
 
 void KNote::createNoteEditor(const QString &configFile)
 {
-    Q_UNUSED(configFile);
+    Q_UNUSED(configFile)
     m_editor = new KNoteEdit(actionCollection(), this);
     m_noteLayout->addWidget(m_editor);
     m_editor->setNote(this);
-    m_editor->installEventFilter(this);   // receive focus events for modified
+    m_editor->installEventFilter(this); // receive focus events for modified
     setFocusProxy(m_editor);
 }
 
 void KNote::slotRequestNewNote()
 {
-    //Be sure to save before to request a new note
+    // Be sure to save before to request a new note
     saveNote();
     Q_EMIT sigRequestNewNote();
 }
@@ -803,7 +790,7 @@ void KNote::createNoteFooter()
     }
 
     // create size grip
-    auto *gripLayout = new QHBoxLayout;
+    auto gripLayout = new QHBoxLayout;
     m_grip = new QSizeGrip(this);
     m_grip->setFixedSize(m_grip->sizeHint());
 
@@ -858,7 +845,7 @@ void KNote::prepare()
     QRect desk = qApp->desktop()->rect();
     desk.adjust(10, 10, -10, -10);
     if (desk.intersects(QRect(position, mDisplayAttribute->size()))) {
-        move(position);             // do before calling show() to avoid flicker
+        move(position); // do before calling show() to avoid flicker
     }
     if (mDisplayAttribute->isHidden()) {
         hide();
@@ -880,8 +867,7 @@ void KNote::prepare()
     int desktop = mDisplayAttribute->desktop();
 
 #if KDEPIM_HAVE_X11
-    if ((desktop < 0 && desktop != NETWinInfo::OnAllDesktops)
-        || !mDisplayAttribute->rememberDesktop()) {
+    if ((desktop < 0 && desktop != NETWinInfo::OnAllDesktops) || !mDisplayAttribute->rememberDesktop()) {
         desktop = KWindowSystem::currentDesktop();
     }
 #endif
@@ -914,12 +900,8 @@ void KNote::prepare()
     // aware of the new colors
     KIconEffect effect;
     const QColor col = mDisplayAttribute->backgroundColor();
-    const QPixmap icon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)),
-                                      KIconEffect::Colorize,
-                                      1, col, false);
-    const QPixmap miniIcon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)),
-                                          KIconEffect::Colorize,
-                                          1, col, false);
+    const QPixmap icon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)), KIconEffect::Colorize, 1, col, false);
+    const QPixmap miniIcon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)), KIconEffect::Colorize, 1, col, false);
     KWindowSystem::setIcons(winId(), icon, miniIcon);
 
     // set up the look&feel of the note
@@ -970,8 +952,8 @@ void KNote::setColor(const QColor &fg, const QColor &bg)
     p.setColor(QPalette::Button, bg.darker(116));
     p.setColor(QPalette::ButtonText, fg);
 
-    //p.setColor( QPalette::Highlight,  bg );
-    //p.setColor( QPalette::HighlightedText, fg );
+    // p.setColor( QPalette::Highlight,  bg );
+    // p.setColor( QPalette::HighlightedText, fg );
 
     // order: Light, Midlight, Button, Mid, Dark, Shadow
 
@@ -994,10 +976,8 @@ void KNote::setColor(const QColor &fg, const QColor &bg)
 
     // update the icon color
     KIconEffect effect;
-    QPixmap icon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)),
-                                KIconEffect::Colorize, 1, bg, false);
-    QPixmap miniIcon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)),
-                                    KIconEffect::Colorize, 1, bg, false);
+    QPixmap icon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_MessageBoxIconSize)), KIconEffect::Colorize, 1, bg, false);
+    QPixmap miniIcon = effect.apply(qApp->windowIcon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)), KIconEffect::Colorize, 1, bg, false);
     KWindowSystem::setIcons(winId(), icon, miniIcon);
     // update the color of the title
     updateFocus();
@@ -1027,7 +1007,7 @@ void KNote::updateFocus()
         } else {
             if (m_tool && !m_tool->isHidden()) {
                 m_tool->hide();
-                updateLayout();     // to update the minimum height
+                updateLayout(); // to update the minimum height
             }
             m_grip->hide();
         }
@@ -1036,7 +1016,7 @@ void KNote::updateFocus()
 
         if (m_tool && !m_tool->isHidden()) {
             m_tool->hide();
-            updateLayout();     // to update the minimum height
+            updateLayout(); // to update the minimum height
         }
     }
 }
@@ -1061,15 +1041,16 @@ void KNote::showEvent(QShowEvent *)
     if (mDisplayAttribute->isHidden()) {
         // KWin does not preserve these properties for hidden windows
         updateKeepAboveBelow(false);
+#if KDEPIM_HAVE_X11
         slotUpdateShowInTaskbar();
+#endif
         toDesktop(mDisplayAttribute->desktop());
         move(mDisplayAttribute->position());
-        auto *attr
-            = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+        auto *attr = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
         saveNoteContent();
         attr->setIsHidden(false);
         if (!mBlockSave) {
-            auto *job = new Akonadi::ItemModifyJob(mItem);
+            auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
             qCDebug(KNOTES_LOG) << "showEvent slotNoteSaved(KJob*)";
 #endif
@@ -1089,7 +1070,7 @@ void KNote::closeEvent(QCloseEvent *event)
     if (qApp->isSavingSession()) {
         return;
     }
-    event->ignore(); //We don't want to close (and delete the widget). Just hide it
+    event->ignore(); // We don't want to close (and delete the widget). Just hide it
     slotClose();
 }
 
@@ -1110,11 +1091,10 @@ void KNote::dropEvent(QDropEvent *e)
     if (md->hasColor()) {
         const QColor bg = qvariant_cast<QColor>(md->colorData());
 
-        auto *attr
-            = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+        auto *attr = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
         saveNoteContent();
         attr->setBackgroundColor(bg);
-        auto *job = new Akonadi::ItemModifyJob(mItem);
+        auto job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "dropEvent slotNoteSaved(KJob*)";
 #endif
@@ -1134,14 +1114,12 @@ bool KNote::event(QEvent *ev)
 
 bool KNote::eventFilter(QObject *o, QEvent *ev)
 {
-    if (ev->type() == QEvent::DragEnter
-        && static_cast<QDragEnterEvent *>(ev)->mimeData()->hasColor()) {
+    if (ev->type() == QEvent::DragEnter && static_cast<QDragEnterEvent *>(ev)->mimeData()->hasColor()) {
         dragEnterEvent(static_cast<QDragEnterEvent *>(ev));
         return true;
     }
 
-    if (ev->type() == QEvent::Drop
-        && static_cast<QDropEvent *>(ev)->mimeData()->hasColor()) {
+    if (ev->type() == QEvent::Drop && static_cast<QDropEvent *>(ev)->mimeData()->hasColor()) {
         dropEvent(static_cast<QDropEvent *>(ev));
         return true;
     }
@@ -1156,23 +1134,19 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
         }
 
         if (ev->type() == QEvent::MouseButtonPress
-            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton
-                || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
+            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
             mOrigPos = e->pos();
             return false;
         }
 
-        if (ev->type() == QEvent::MouseMove
-            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton
-                || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
+        if (ev->type() == QEvent::MouseMove && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
             QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
             move(newPos);
             return true;
         }
 
         if (ev->type() == QEvent::MouseButtonRelease
-            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton
-                || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
+            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
             QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
             move(newPos);
             return false;
@@ -1182,7 +1156,7 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
 
     if (o == m_editor) {
         if (ev->type() == QEvent::FocusOut) {
-            auto *fe = static_cast<QFocusEvent *>(ev);
+            auto fe = static_cast<QFocusEvent *>(ev);
             if (fe->reason() != Qt::PopupFocusReason && fe->reason() != Qt::MouseFocusReason) {
                 updateFocus();
                 if (!mBlockSave) {
