@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "knoteutils.h"
+#include "attributes/notedisplayattribute.h"
 #include "knotes_debug.h"
 #include "knotesglobalconfig.h"
-#include "attributes/notedisplayattribute.h"
 
 #include <AkonadiCore/ServerManager>
 
@@ -15,8 +15,7 @@
 
 void KNoteUtils::updateConfiguration()
 {
-    QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent,
-                                                               QStringLiteral("akonadi_notes_agent"));
+    QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_notes_agent"));
 
     QDBusInterface interface(service, QStringLiteral("/NotesAgent"));
     if (interface.isValid()) {
@@ -28,8 +27,7 @@ void KNoteUtils::updateConfiguration()
 
 void KNoteUtils::setDefaultValue(Akonadi::Item &item)
 {
-    auto *attribute
-        = item.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    auto *attribute = item.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
 
     attribute->setBackgroundColor(KNotesGlobalConfig::self()->bgColor());
     attribute->setForegroundColor(KNotesGlobalConfig::self()->fgColor());
